# AWS Connector

This tool provides a AWS CLI connector where you can switch roles to the account you want access to.

# Get started
## Generate config
Copy the file config/config_template.yaml to ~/.aws/aws-connector/config.yaml and fill in the file before you start.

## Start the tool
```
 python3 /usr/local/bin/awsc
```
